===============================
PyMCQ
===============================

.. image:: https://badge.fury.io/py/pymcq.png
    :target: http://badge.fury.io/py/pymcq

.. image:: https://travis-ci.org/sglumac/pymcq.png?branch=master
        :target: https://travis-ci.org/sglumac/pymcq

.. image:: https://pypip.in/d/pymcq/badge.png
        :target: https://pypi.python.org/pypi/pymcq


This is a project that integrates latex exam into pyhon for easier creating of mcq tests.

* Free software: BSD license
* Documentation: https://pymcq.readthedocs.org.

Features
--------

* TODO